@@ -8,11 +8,13 @@ from contextlib import suppress
 from functools import wraps
 from shutil import copy2
 from types import FunctionType
+import logging
 
 import numpy as np
 from PyQt5 import QtCore
 
 from .. import AbstractRawDataset, DiffractionDataset, PowderDiffractionDataset
+from .qlogger import QLogger
 
 
 def error_aware(func):
@@ -119,6 +121,33 @@ class IrisController(QtCore.QObject, metaclass=ErrorAware):
         self._averaged_data_container = None
         self._average_time_series_container = None
 
+        self.logger = QLogger(parent=self)
+        self.logger.debug("Controller started.")
+
+        # A lot of info-level messages should be mirrored between the status
+        # bar and the info log
+        # Similarly, the error messages from ErrorAware type should be
+        # mirrored in the error log
+        self.status_message_signal.connect(self.logger.info)
+        self.error_message_signal.connect(self.logger.error)
+
+    @QtCore.pyqtSlot(str)
+    @QtCore.pyqtSlot(str, object)
+    def log(self, message, level=logging.INFO):
+        """
+        Interface to the iris logger.
+
+        ALL logging should go through the controller.
+
+        Parameters
+        ----------
+        message : str
+            Logging message
+        level : logging.Level, optional
+            Level of the logging message.
+        """
+        self.logger.log(message, level)
+
     @QtCore.pyqtSlot(int, int)
     def display_raw_data(self, timedelay_index, scan):
         """
@@ -415,6 +444,14 @@ class IrisController(QtCore.QObject, metaclass=ErrorAware):
             else:
                 is_powder = False
 
+        # For powder datasets, there might be the creation of placeholder datasets
+        # therefore, we open the file and do nothing
+        # TODO: stop writing datasets in PowderDiffractionDataset.__init__
+        #       since the GUI will only open datasets in read-mode by default
+        if cls is PowderDiffractionDataset:
+            with cls(path, mode='r+'):
+                pass
+        
         self.dataset = cls(path, mode="r")
         self.dataset_metadata.emit(self.dataset.metadata)
 
