@@ -8,7 +8,6 @@ from pathlib import Path
 
 import pyqtgraph as pg
 from PyQt5 import QtCore, QtGui, QtWidgets
-
 from skued import diffread
 
 # Get all proper subclasses of AbstractRawDataset
@@ -24,10 +23,11 @@ from .metadata_edit_dialog import MetadataEditDialog
 from .powder_viewer import PowderViewer
 from .processing_dialog import ProcessingDialog
 from .qbusyindicator import QBusyIndicator
+from .qlogger import LOG_DIRECTORY
 from .symmetrize_dialog import SymmetrizeDialog
 from .update import UpdateChecker
 
-image_folder = join(dirname(__file__), "images")
+IMAGE_FOLDER = join(dirname(__file__), "images")
 
 LOAD_PLUGIN_HELP = """You will be prompted to select a plug-in file. This file will be COPIED into:
 
@@ -116,7 +116,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         # Including custom 'busy' indicator
         status_bar = QtWidgets.QStatusBar(parent=self)
         self.controller.status_message_signal.connect(
-            lambda msg: status_bar.showMessage(msg, 10e3)
+            lambda msg: status_bar.showMessage(msg, 20e3)
         )
         self.setStatusBar(status_bar)
 
@@ -194,19 +194,19 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
             self._create_load_raw(cls, load_raw_submenu)
 
         self.load_dataset_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "locator.png")), "& Load dataset", self
+            QtGui.QIcon(join(IMAGE_FOLDER, "locator.png")), "& Load dataset", self
         )
         self.load_dataset_action.triggered.connect(self.load_dataset)
 
         self.load_single_picture_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "locator.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "locator.png")),
             "& Load diffraction picture",
             self,
         )
         self.load_single_picture_action.triggered.connect(self.load_single_picture)
 
         self.close_raw_dataset_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "locator.png")), "& Close raw dataset", self
+            QtGui.QIcon(join(IMAGE_FOLDER, "locator.png")), "& Close raw dataset", self
         )
         self.close_raw_dataset_action.triggered.connect(
             self.controller.close_raw_dataset
@@ -217,7 +217,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.close_dataset_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "locator.png")), "& Close dataset", self
+            QtGui.QIcon(join(IMAGE_FOLDER, "locator.png")), "& Close dataset", self
         )
         self.close_dataset_action.triggered.connect(self.controller.close_dataset)
         self.close_dataset_action.setEnabled(False)
@@ -237,7 +237,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         ###################
         # Plug-in Actions
         self.load_plugin_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "eye.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "eye.png")),
             "& Install plug-in (restarts program)",
             self,
         )
@@ -250,7 +250,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )  # wouldn't want to restart during processing
 
         self.open_plugin_directory_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "eye.png")), "& Open plug-in directory", self
+            QtGui.QIcon(join(IMAGE_FOLDER, "eye.png")), "& Open plug-in directory", self
         )
         self.open_plugin_directory_action.triggered.connect(
             lambda: QtGui.QDesktopServices.openUrl(
@@ -259,7 +259,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.howto_write_plugin_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "revert.png")), "& Writing a plug-in", self
+            QtGui.QIcon(join(IMAGE_FOLDER, "revert.png")), "& Writing a plug-in", self
         )
         self.howto_write_plugin_action.triggered.connect(
             lambda: QtGui.QDesktopServices.openUrl(
@@ -276,7 +276,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         ###################
         # Operations on Diffraction Datasets
         self.processing_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "analysis.png")), "& Process raw data", self
+            QtGui.QIcon(join(IMAGE_FOLDER, "analysis.png")), "& Process raw data", self
         )
         self.processing_action.triggered.connect(self.launch_processsing_dialog)
         self.controller.raw_dataset_loaded_signal.connect(
@@ -284,7 +284,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.symmetrize_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "analysis.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "analysis.png")),
             "& Symmetrize data (beta)",
             self,
         )
@@ -294,7 +294,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.calculate_azimuthal_averages_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "analysis.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "analysis.png")),
             "& Calculate azimuthal averages",
             self,
         )
@@ -306,7 +306,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.update_metadata_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "save.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "save.png")),
             "& Update dataset metadata",
             self,
         )
@@ -316,7 +316,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.calibrate_scattvector_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "analysis.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "analysis.png")),
             "& Calibrate scattering vector",
             self,
         )
@@ -441,7 +441,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         self.about_action.triggered.connect(self.show_about)
 
         self.launch_documentation_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "revert.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "revert.png")),
             "& Open online documentation",
             self,
         )
@@ -452,7 +452,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.goto_repository_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "revert.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "revert.png")),
             "& Go to GitHub Repository",
             self,
         )
@@ -463,7 +463,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.report_issue_action = QtWidgets.QAction(
-            QtGui.QIcon(join(image_folder, "revert.png")), "& Report issue", self
+            QtGui.QIcon(join(IMAGE_FOLDER, "revert.png")), "& Report issue", self
         )
         self.report_issue_action.triggered.connect(
             lambda: QtGui.QDesktopServices.openUrl(
@@ -471,7 +471,15 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
             )
         )
 
-        self.update_action = QtWidgets.QAction("& Download the latest version", self)
+        self.open_log_directory_action = QtWidgets.QAction("& Open log directory", self)
+        self.open_log_directory_action.triggered.connect(
+            lambda: QtGui.QDesktopServices.openUrl(
+                QtCore.QUrl("file:///" + str(LOG_DIRECTORY))
+            )
+        )
+
+        # When iris starts, no knowledge if update is available
+        self.update_action = QtWidgets.QAction("& Checking for updates...", self)
         self.update_action.triggered.connect(
             lambda: QtGui.QDesktopServices.openUrl(
                 QtCore.QUrl("https://github.com/LaurentRDC/iris-ued/releases/latest")
@@ -488,6 +496,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         self.help_menu.addAction(self.goto_repository_action)
         self.help_menu.addAction(self.report_issue_action)
         self.help_menu.addSeparator()
+        self.help_menu.addAction(self.open_log_directory_action)
         self.help_menu.addAction(self.update_action)
 
         ###################
@@ -517,24 +526,27 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         available.setSize(0.75 * available.size())
         self.setGeometry(available)
 
-        self.setWindowIcon(QtGui.QIcon(join(image_folder, "eye.png")))
+        self.setWindowIcon(QtGui.QIcon(join(IMAGE_FOLDER, "eye.png")))
         self.setWindowTitle("Iris - UED data exploration")
         self.center_window()
         self.showMaximized()
 
         # At the end, we start the check for an update
         # This is done in a separate thread to prevent slow startups
+        # Note: the update status signal is passed to the controller
+        # so it can be logged as well.
         self.update_checker = UpdateChecker(parent=self)
-        self.update_checker.update_available_signal.connect(
-            self.update_action.setEnabled
+        self.update_checker.update_status_signal.connect(
+            self.controller.status_message_signal
         )
+        self.update_checker.update_available_signal.connect(self.update_available)
         self.update_checker.start()
 
     def _create_load_raw(self, cls, submenu):
         # Note : because of dynamical nature of these bindings,
         # it must be done in a separate method
         return submenu.addAction(
-            QtGui.QIcon(join(image_folder, "locator.png")),
+            QtGui.QIcon(join(IMAGE_FOLDER, "locator.png")),
             "&Load {}".format(cls.__name__),
             lambda: self.load_raw_dataset(cls),
         )
@@ -627,6 +639,16 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         dialog.exec_()
         dialog.calibration_parameters.disconnect(self.controller.powder_calq)
 
+    @QtCore.pyqtSlot(bool)
+    def update_available(self, available):
+        """ Handle UI in case an update is available or not. """
+        if available:
+            self.update_action.setEnabled(True)
+            self.update_action.setText("An update is available!")
+        else:
+            self.update_action.setEnabled(False)
+            self.update_action.setText("No updates available.")
+
     @QtCore.pyqtSlot(object)
     def load_raw_dataset(self, cls):
         path = self.file_dialog.getExistingDirectory(
